#
# Conditional build:
%bcond_with	tests	# unit tests
%bcond_without	doc	# ri/rdoc documentation

%define pkgname RMagick
Summary:	Graphics Processing library for Ruby
Summary(pl.UTF-8):	Biblioteka przetwarzania grafiki dla języka Ruby
Name:		ruby-%{pkgname}
Version:	4.1.0
Release:	3
License:	Ruby-alike
Group:		Development/Languages
Source0:	http://rubygems.org/downloads/rmagick-%{version}.gem
# Source0-md5:	e22024f2c78088f101ff0acade179043
Patch0:		no-gem.patch
Patch1:		no-git.patch
URL:		https://github.com/gemhome/rmagick
BuildRequires:	ImageMagick-devel >= 1:7.0.0
BuildRequires:	ruby-test-unit
BuildRequires:	gmp-devel
BuildRequires:	rpm-rubyprov
BuildRequires:	rpmbuild(macros) >= 1.484
BuildRequires:	ruby >= 1:1.8.6
BuildRequires:	ruby-devel
BuildRequires:	ruby-modules
BuildRequires:	ruby-rake
BuildRequires:	ruby-rake-compiler
BuildRequires:	ruby-simplecov
BuildRequires:	ruby-rspec-core
BuildRequires:	ruby-rspec-expectations
BuildRequires:	ruby-rspec-mocks
%if %{with tests}
BuildRequires:	ImageMagick-coder-dot
BuildRequires:	ImageMagick-coder-fpx
BuildRequires:	ImageMagick-coder-jbig
BuildRequires:	ImageMagick-coder-jpeg
BuildRequires:	ImageMagick-coder-jpeg2
BuildRequires:	ImageMagick-coder-miff
BuildRequires:	ImageMagick-coder-mpr
BuildRequires:	ImageMagick-coder-pdf
BuildRequires:	ImageMagick-coder-png
BuildRequires:	ImageMagick-coder-ps2
BuildRequires:	ImageMagick-coder-svg
BuildRequires:	ImageMagick-coder-tiff
BuildRequires:	ImageMagick-coder-url
BuildRequires:	ImageMagick-coder-wmf
%endif
%if %{with doc}
BuildRequires:	ruby-rdoc
%endif
BuildConflicts:	ruby-RMagick < 1.7.2
%requires_ge_to	ImageMagick-libs ImageMagick-devel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
An interface to the ImageMagick and GraphicsMagick image processing
libraries. Supports more than 80 image formats, including GIF, JPEG,
PNG. Includes 2D drawing API. Comprehensive HTML documentation.

%description -l pl.UTF-8
Jest to interfejs do bibliotek przetwarzania grafiki ImageMagick i
GraphicsMagick. Obsługuje ponad 80 formatów graficznych, włączając w
to GIF, JPEG, PNG. Zawiera API dla dwuwymiarowego rysowania. Obszerna
dokumentacja w HTML-u.

%package rdoc
Summary:	HTML documentation for Ruby %{pkgname} module
Summary(pl.UTF-8):	Dokumentacja w formacie HTML dla modułu języka Ruby %{pkgname}
Group:		Documentation
Requires:	ruby >= 1:1.8.7-4
BuildArch:	noarch

%description rdoc
HTML documentation for Ruby %{pkgname} module.

%description rdoc -l pl.UTF-8
Dokumentacja w formacie HTML dla modułu języka Ruby %{pkgname}.

%package ri
Summary:	ri documentation for Ruby %{pkgname} module
Summary(pl.UTF-8):	Dokumentacja w formacie ri dla modułu języka Ruby %{pkgname}
Group:		Documentation
Requires:	ruby
BuildArch:	noarch

%description ri
ri documentation for Ruby %{pkgname} module.

%description ri -l pl.UTF-8
Dokumentacja w formacie ri dla modułu języka Ruby %{pkgname}.

%prep
%setup -q -n rmagick-%{version}
%patch0 -p1
%patch1 -p1

%build
# make gemspec self-contained
ruby -r rubygems -e 'spec = eval(File.read("rmagick-%{version}.gemspec"))
	File.open("%{pkgname}-%{version}.gemspec", "w") do |file|
	file.puts spec.to_ruby_for_cache
end' #'

rake compile \
	CC="%{__cc}" \
	LDFLAGS="%{rpmldflags}" \
	CFLAGS="%{rpmcflags} -fPIC"

%if %{with tests}
rake spec
rake test
%endif

%if %{with doc}
rdoc --ri --op ri ext/RMagick lib
rdoc --op rdoc ext/RMagick lib
%{__rm} ri/created.rid
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{ruby_vendorlibdir},%{ruby_vendorarchdir},%{ruby_ridir},%{ruby_specdir},%{ruby_rdocdir}/%{name}-%{version}}

cp -a lib/* $RPM_BUILD_ROOT%{ruby_vendorlibdir}
%{__rm} $RPM_BUILD_ROOT%{ruby_vendorlibdir}/RMagick2.so

# install ext
install -p lib/RMagick2.so $RPM_BUILD_ROOT%{ruby_vendorarchdir}

%if %{with doc}
cp -a ri/* $RPM_BUILD_ROOT%{ruby_ridir}
cp -a rdoc/* $RPM_BUILD_ROOT%{ruby_rdocdir}/%{name}-%{version}
%endif

# install gemspec
cp -p %{pkgname}-%{version}.gemspec $RPM_BUILD_ROOT%{ruby_specdir}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGELOG.md CODE_OF_CONDUCT.md CONTRIBUTING.md LICENSE README.md
%{ruby_vendorlibdir}/rmagick
%{ruby_vendorlibdir}/rmagick*.rb
%{ruby_vendorlibdir}/rvg
%attr(755,root,root) %{ruby_vendorarchdir}/RMagick2.so
%{ruby_specdir}/%{pkgname}-%{version}.gemspec

%if %{with doc}
%files rdoc
%defattr(644,root,root,755)
%{ruby_rdocdir}/%{name}-%{version}

%files ri
%defattr(644,root,root,755)
%{ruby_ridir}/Magick
%{ruby_ridir}/RMagick
%endif
%changelog
* Sat Apr 16 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/ruby-RMagick.git;a=log;h=master

* Sat Apr 16 2022 Jan Rękorajski <baggins@pld-linux.org> 6f8d2cf
- Release 3 (by relup.sh)

* Sat Apr 16 2022 Jan Rękorajski <baggins@pld-linux.org> 6404d44
- rediff patch and update build process for rpm 4

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> f614652
- unconditional noarch subpackages

* Fri Jan 29 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> b10b1b5
- release 2 (by relup.sh)

* Tue Mar 24 2020 Jan Rękorajski <baggins@pld-linux.org> 2b0c9c6
- updated no-git patch

* Tue Mar 24 2020 Jan Rękorajski <baggins@pld-linux.org> b275c83
- updated no-gem patch

* Tue Mar 24 2020 Jan Rękorajski <baggins@pld-linux.org> 6baf007
- up to 4.1.0, finally with support for ImageMagick 7

* Wed Jan 09 2019 Jakub Bogusz <qboosh@pld-linux.org> 6db7bf1
- release 7 (ImageMagick6 soname change)

* Sun Jun 10 2018 Jan Rękorajski <baggins@pld-linux.org> 9520e33
- release 6 (by relup.sh)

* Tue Dec 26 2017 Jan Rękorajski <baggins@pld-linux.org> 18b3120
- release 5 (by relup.sh)

* Sun Nov 12 2017 Jan Rękorajski <baggins@pld-linux.org> 0440f68
- disable tests (test loader broken on ruby 2.3)
- rel 4

* Fri Oct 27 2017 Elan Ruusamäe <glen@delfi.ee> ac9d822
- update BR deps

* Thu Oct 26 2017 Elan Ruusamäe <glen@pld-linux.org> 096e6d6
- add tests and doc bcond

* Wed Oct 25 2017 Jan Rękorajski <baggins@pld-linux.org> ecd9015
- rebuild with ruby 2.3
- release 3 (by relup.sh)

* Tue Jun 06 2017 Jan Rękorajski <baggins@pld-linux.org> 4d470cf
- release 2 (by relup.sh)

* Mon Jun 05 2017 Jakub Bogusz <qboosh@pld-linux.org> 5c15237
- unified examples dir
- package LICENSE
- don't package CONTRIBUTING (contributors already have sources)

* Tue Dec 27 2016 Jan Rękorajski <baggins@pld-linux.org> f5b8535
- make sure correct ImageMagick version is used

* Tue Dec 27 2016 Jan Rękorajski <baggins@pld-linux.org> 2c63a37
- up to 2.16.0
- requires ImageMagick6

* Mon May 23 2016 Elan Ruusamäe <glen@delfi.ee> 62fd30b
- ImageMagick-6.9.4.1 rebuild
- release 7 (by relup.sh)

* Wed May 04 2016 Elan Ruusamäe <glen@delfi.ee> 266e93f
- >= is probably fine too; refs 38497807

